# Minima-Scholar

**Minima-Scholar** is a Jekyll theme for academic websites, enabling
simple management and publication of data on team members and
publications.

## Sources and rationale

[Jekyll](http://jekyllrb.com) is a tool for generating websites from
simple, easy to write and easy to read text files formatted in
[Markdown](https://en.wikipedia.org/wiki/Markdown). Jekyll websites can
be hosted for free on [GitHub Pages](https://pages.github.com) and
require minimal technical knowledge or effort to maintain.

This theme is a fork from the excellent Jekyll default theme
[minima](https://github.com/jekyll/minima) designed by Parker Moore.
**Minima-Scholar** introduces some additional features useful for
academics and research labs, while striving to remain compatible with
future releases of **Minima**. It is also inspired by some other
venerable Jekyll themes such as
[AcademicPages](https://academicpages.github.io) and
Gabriel Alcaras'
[Academic](https://github.com/gaalcaras/academic).

## Features

**Minima-Scholar** behaves mostly like the original **Minima** and is
designed to be fully compatible with GitHub Pages. It moves a step
closer than Minima towards the
[Semantic Web](https://en.wikipedia.org/wiki/Semantic_Web), however, in
supporting the schema.org vocabulary wherever feasible.
**Minima-Scholar** supports, out of the box:

- Team member lists read from schema.org compliant YAML data files (an
  example file is provided to get you started).
- Publication lists read from CSL-Yaml files as directly exported from
  [Zotero](https://zotero.org) using the
  [Better BibTeX plugin](https://retorque.re/zotero-better-bibtex/).

## Installation

Add this line to your Jekyll site's Gemfile:

```ruby
gem "minima-scholar"
```

And then execute:

    $ bundle


## Contents At-A-Glance

This section only covers the features of **Minima-Scholar** that differ
from the original **Minima**. Refer to the
[Minima repository](https://github.com/jekyll/minima) for further
information.

### Layouts

Refers to files within the `_layouts` directory, that define the markup for your theme.

- `biblio.html` &mdash; This layout generates a list of bibliographic
  references from the file `_data/biblio.yaml`, which is expected to be
  a CSL-compliant YAML file generated by Zotero and Better BibLaTeX
  (please let me know if it works with other exporters, or how to make
  it work with your favorite program). Currently it uses the Chicago
  format, though others may be added in the future.
- `team.html` &mdash; This layout outputs a list of team members, in
  alphabetical order or last names, with links to their
  [ORCID](https://orcid.org) profiles and to their CV (or whatever
  personal website they might have). It reads data from the `_team`
  collection that is compliant with the schema.org specification.
- `page.html` &mdash; This standard Minima layout has been extended with
  the addition of Author and Date fields, which will render only when
  the corresponding front matter information is available. The Author
  front matter is expected to be structured as follows:

```yaml
author:
- name: "First Author"
  affiliation: "University 1"
- name: "Second Author"
  affiliation: "Another School"
```

### Includes

Refers to snippets of code within the `_includes` directory that can be inserted in multiple layouts (and another include-file as well) within the same theme-gem.

- `share.html` &mdash; Links for sharing page content on various social
  media.
- `header.html` &mdash; Defines the site's main header section. This
  file has been modified from the original **Minima** version: here, it
  allows you to use an image instead of your website's title as text.

### Plugins

**Minima-scholar** requires no additional plugins other than those
already included by **Minima** and is fully compatible with the plugin
restrictions imposed by GitHub Pages.

## Usage

Have the following line in your `_config.yml` file:

```yaml
remote_theme: p3palazzo/minima-scholar
```


### Customizing templates

See the [Minima](https://github.com/jekyll/minima) README on how to
customize the appearance of your website.

### Customize navigation links

This allows you to set which pages you want to appear in the navigation area and configure order of the links.

The default setup in **Minima-Scholar** is to have navigation links to
your lab's about page, to it publications list, and to the list of lab
members, in `_config.yml`:

```yaml
header_pages:
  - about.md
  - team.md
  - biblio.md
```

## Contributing

Bug reports and feature contributions are welcome on GitHub at
https://github.com/p3palazzo/minima-scholar.

## License

The theme is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

